@@ -3,7 +3,9 @@
 #'
 #' @description Performs pairwise two-sample ordinal regression across groups
 #'              for paired or blocked data.
-#' 
+#' @param formula A formula indicating the measurement variable and
+#'                the grouping variable. e.g. y ~ group | block.
+#' @param data   The data frame to use.                
 #' @param x      The response variable as a vector.
 #' @param g      The grouping variable as a vector.
 #' @param b      The blocking variable as a vector.
@@ -12,7 +14,9 @@
 #' @param ...    Additional arguments passed to
 #'               \code{\link{clmm}}.               
 #'             
-#' @details 
+#' @details The input should include either \code{formula} and \code{data};
+#'          or \code{x}, \code{g}, and \code{b}.
+#'          
 #'          Ordinal regression 
 #'          is analogous to general linear regression or generalized linear
 #'          regression for cases where 
@@ -39,23 +43,26 @@
 #'         A matrix of p-values;
 #'         The p-value adjustment method;
 #'         A matrix of adjusted p-values. 
-#'         
+#'
+#' @note    The parsing of the formula is simplistic. 
+#'          The first variable on the
+#'          left side is used as the measurement variable.  
+#'          The first variable on the
+#'          right side is used for the grouping variable.
+#'          The second variable on the
+#'          right side is used for the blocking variable
+#'
 #' @examples
 #' data(BobBelcher)
 #' BobBelcher$Likert.f = factor(BobBelcher$Likert, ordered = TRUE)
-#' BobBelcher$Instructor = factor(BobBelcher$Instructor,
-#'                                levels=c("Linda Belcher", "Louise Belcher",
-#'                                  "Tina Belcher", "Bob Belcher",
-#'                                  "Gene Belcher"))
-#' BobBelcher = BobBelcher[order(factor(BobBelcher$Instructor, 
-#'                         levels=c("Linda Belcher", "Louise Belcher",
-#'                                  "Tina Belcher", "Bob Belcher",
-#'                                  "Gene Belcher"))),]               
-#' PT = pairwiseOrdinalPairedMatrix(x      = BobBelcher$Likert.f,
-#'                                  g      = BobBelcher$Instructor,
-#'                                  b      = BobBelcher$Rater,
-#'                                  threshold="equidistant",
-#'                                  method = "fdr")$Adjusted
+#' BobBelcher$Instructor = factor( BobBelcher$Instructor, 
+#'                   levels = c("Linda Belcher", "Louise Belcher",
+#'                              "Tina Belcher", "Bob Belcher",
+#'                              "Gene Belcher")) 
+#' PT = pairwiseOrdinalPairedMatrix(Likert.f ~ Instructor | Rater,
+#'                                  data      = BobBelcher,
+#'                                  threshold ="equidistant",
+#'                                  method    = "fdr")$Adjusted
 #' PT
 #' library(multcompView)
 #' multcompLetters(PT,
@@ -69,8 +76,15 @@
 #' @export
 
 pairwiseOrdinalPairedMatrix = 
-  function(x, g, b, method = "fdr", ...)
+  function(formula=NULL, data=NULL,
+           x=NULL, g=NULL, b=NULL, 
+           method = "fdr", ...)
   {
+  if(!is.null(formula)){
+    x  = eval(parse(text=paste0("data","$",all.vars(formula[[2]])[1])))
+    g  = eval(parse(text=paste0("data","$",all.vars(formula[[3]])[1])))
+    b  = eval(parse(text=paste0("data","$",all.vars(formula[[3]])[2])))
+    }
   n = length(levels(g))
   N = n*n
   d = data.frame(x = x, g = g, b = b)
