@@ -2,6 +2,9 @@
 #'
 #' @description Performs pairwise two-sample ordinal regression across groups.
 #' 
+#' @param formula A formula indicating the measurement variable and
+#'                the grouping variable. e.g. y ~ group.
+#' @param data   The data frame to use.
 #' @param x      The response variable as a vector.
 #' @param g      The grouping variable as a vector.
 #' @param method The p-value adjustment method to use for multiple tests.
@@ -9,7 +12,9 @@
 #' @param ...    Additional arguments passed to
 #'               \code{\link{clm}}.               
 #'             
-#' @details 
+#' @details The input should include either \code{formula} and \code{data};
+#'          or \code{x}, and \code{g}.
+#'          
 #'          Ordinal regression 
 #'          is analogous to general linear regression or generalized linear
 #'          regression for cases where 
@@ -30,15 +35,21 @@
 #' @seealso \code{\link{pairwiseOrdinalMatrix}}
 #' @concept ordinal regression post-hoc one-way
 #' @return A dataframe of the groups being compared, the p-values,
-#'         and the adjusted p-values. 
+#'         and the adjusted p-values.
 #'         
+#' @note    The parsing of the formula is simplistic. 
+#'          The first variable on the
+#'          left side is used as the measurement variable.  
+#'          The first variable on the
+#'          right side is used for the grouping variable.
+#'          
 #' @examples
 #' data(PoohPiglet)
 #' PoohPiglet$Likert.f = factor(PoohPiglet$Likert, ordered = TRUE)
-#' PoohPiglet$Speaker = factor(PoohPiglet$Speaker, 
-#'                         levels=c("Pooh", "Tigger", "Piglet"))
-#' PT = pairwiseOrdinalTest(x      = PoohPiglet$Likert.f,
-#'                          g      = PoohPiglet$Speaker,
+#' PoohPiglet$Speaker = factor(PoohPiglet$Speaker,
+#'                      levels = c("Pooh", "Tigger", "Piglet"))
+#' PT = pairwiseOrdinalTest(Likert.f ~ Speaker,
+#'                          data   = PoohPiglet,
 #'                          method = "fdr")
 #' PT
 #' cldList(comparison = PT$Comparison,
@@ -51,8 +62,14 @@
 #' @export
 
 pairwiseOrdinalTest = 
-  function(x, g, method = "fdr", ...)
+  function(formula=NULL, data=NULL,
+           x=NULL, g=NULL, 
+           method = "fdr", ...)
   {
+    if(!is.null(formula)){
+    x  = eval(parse(text=paste0("data","$",all.vars(formula[[2]])[1])))
+    g  = eval(parse(text=paste0("data","$",all.vars(formula[[3]])[1])))
+    }
   if(!is.factor(g)){g=factor(g)}
   n = length(levels(g))
   N = n*(n-1)/2
